// Kass's Customizable Node/Particles Title

// settings:
const canvasName = "did-canvas"
var maxNodes = isOnMobileDevice() ? 20 : 40 // using too many will impact performance.
const nodeMinSize = 3
const nodeMaxSize = 4
const nodeMinSpeed = 0.02
const nodeMaxSpeed = 0.3
const nodeMaxConnections = 20
const connectionThickness = 2;
const connectionDist = 102
const connectionColor = "#0f477e"
const nodeColors = ['#0f477e'] // you may enter multiple colors ["#65c665", "#40a040"]
const warpEdges = false // if false nodes will bounce off the edges
const useIcon = false // if false then colored circles will be used
const iconPath = "https://image.flaticon.com/icons/png/128/137/137068.png"
const iconScale = 6
const useTrail  = false
const backgroundColor = "#222222"
// another example can be found here https://codepen.io/cryptokass/pen/mgbajy?editors=0010

// canvas reference:
var canvas = document.getElementById(canvasName)
var ctx = canvas.getContext('2d')

// store canvas size:
let canvasHeight = +getComputedStyle(canvas).getPropertyValue("height").slice(0, -2);
let canvasWidth = +getComputedStyle(canvas).getPropertyValue("width").slice(0, -2);

canvas.height = canvasHeight
canvas.width = canvasWidth

// setup image
var img = new Image()
img.src = iconPath

// animation frame compatibility:
window.requestAnimFrame = function()
	{
		return (
			window.requestAnimationFrame       || 
			window.webkitRequestAnimationFrame || 
			window.mozRequestAnimationFrame    || 
			window.oRequestAnimationFrame      || 
			window.msRequestAnimationFrame     || 
			function(callback) { window.setTimeout(callback, 1000 / 60) }
		);
}()

//mobile check
function isOnMobileDevice() {
  var check = false;
  (function(a){if(/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino/i.test(a)||/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(a.substr(0,4))) check = true;})(navigator.userAgent||navigator.vendor||window.opera);
  return check;
};

// node class
function Node(){
  
  this.size = nodeMinSize + Math.random() * (nodeMaxSize-nodeMinSize)
  this.x = canvasWidth * Math.random()
  this.y = canvasHeight * Math.random()
  this.color = nodeColors[Math.floor(Math.random()*nodeColors.length)]
  this.connections = 0
  
  // calculate starting velocity
  let speed = nodeMinSpeed + Math.random() * (nodeMaxSpeed-nodeMinSpeed)
  let theta = Math.random() * Math.PI * 2
  this.velocity = {x:speed * Math.sin(theta), y:speed * Math.cos(theta)}
  
  // move this node
  this.move = function(){
    if (this.x + this.velocity.x >= canvas.width || this.x + this.velocity.x <= 0){
      if (warpEdges){
        this.x = (this.x + this.velocity.x >= canvas.width ) ? 0 : canvas.width
      } else {
        this.velocity.x = -this.velocity.x
      }
    }
    if (this.y + this.velocity.y >= canvas.height || this.y + this.velocity.y <= 0)
      {
        if (warpEdges) {
          this.y = (this.y + this.velocity.y >= canvas.height ) ? 0 : canvas.height
        } else {
          this.velocity.y = -this.velocity.y
        }
        
      }
    this.x += this.velocity.x
    this.y += this.velocity.y
    this.connections = 0
  }
  
  // draw this nodes connections
  this.drawConnections = function(index){
    for (let i=index+1; i < nodes.length; i++){
      let node = nodes[i]
      let dist = Math.sqrt(Math.pow(this.x - node.x,2) + Math.pow(this.y - node.y,2))
      
      if (dist < connectionDist && node.connections < nodeMaxConnections && this.connections < nodeMaxConnections){
        ctx.globalAlpha = 1-dist/connectionDist
        ctx.beginPath()
        ctx.moveTo(this.x,this.y)
        ctx.lineTo(node.x, node.y)
        ctx.lineWidth = connectionThickness
        ctx.strokeStyle = connectionColor
        ctx.stroke()
        ctx.closePath()
        node.connections++
        this.connections++
      }
    }
  }
  
  this.draw = function(){
    ctx.globalAlpha = 1
    if (useIcon){
      let _size = this.size * iconScale
      let dx = this.x - _size/2
      let dy = this.y - _size/2
      ctx.drawImage(img, dx, dy, _size, _size)
    }else{
      ctx.beginPath()
      ctx.arc(this.x, this.y, this.size, 0, Math.PI * 2)
      ctx.fillStyle = this.color
      ctx.fill()
      ctx.closePath()
    }
  }
}

var nodes = []
for (let i=0; i < maxNodes; i++){
  var node = new Node()
  nodes.push(node)
}

function tick(){
  if (useTrail){
    ctx.globalAlpha = 0.1
    ctx.rect(0,0,canvas.width, canvas.height)
    ctx.fillStyle = backgroundColor
    ctx.fill()
  }else{
   ctx.clearRect(0, 0, canvas.width, canvas.height)
  }
  for (let i=0; i < maxNodes; i++){
    nodes[i].drawConnections(i)
  }
  for (let i=0; i < maxNodes; i++){
    nodes[i].draw()
    nodes[i].move()
  }
  requestAnimFrame(tick);
}

requestAnimFrame(tick);