---
layout      : "single"
title       : Identity Decentralized
description : "Resources for Creating a Vendor Agnostic, User-Controlled, Identity Layer for the Internet."
twitter:
  card      : "summary_large_image"
header:
  image     : "https://infominer.id/DIDecentralized/assets/img/didecentral.png"

---

<center><img src="assets/img/didecentral.png"/></center>


>A good self‐sovereign identity system will allow individuals to directly influence how companies, governments, and others correlate our interactions across different services and locations by default. It won’t fix all identity problems nor preclude alternative identity approaches, but it will put the individual in control of most uses of identity and give organizations a simpler, easier, more ethical way to use identity to improve how they provide services and products. When successful, it will not only enable individuals to exercise greater control over how companies and governments keep track of us, it will also illuminate those situations where self‐sovereign identity is restricted, facilitating a conversation about when and where such limits are appropriate. [Joe Andrieu -A Technology‐Free Definition of Self‐Sovereign Identity](https://github.com/jandrieu/rebooting-the-web-of-trust-fall2016/blob/master/topics-and-advance-readings/a-technology-free-definition-of-self-sovereign-identity.pdf)

## Note:

I'm beginning to realize that the more accessible this becomes as a web-page, the less accessible it becomes as a directory on GitHub. I guess that's ok, I'm not really sure. I plan to set up comments soon, and find other ways for visitors to easily offer feedback. For example, I feel like the desktop font was too big so I reduced it, but now I wonder if the mobile font is too small.. and I'm going to try and adjust that.. but it would be helpful to know what your experience is.

And yeah, I'm still working out the deets with the logos... Other than that I'm super excited about how well this site works now :D Those logos will drive me nuts until I figure out something that looks good, but really I need to focus on something else for the moment.

As you can see, I'm continually working to break up the info into separate files, so it can all grow. If a page looks empty, feel free to share any links you have and\or submit a few sentences. Otherwise, hold tight. There is a vision, it's all coming together..


[[**T**](#contents)]witter • [[**G**](#contents)]ithub • [[**B**](#contents)]log • [[**wp**](#contents)] whitepaper • [[**D**](#contents)]ocumentation • [[**F**](#contents)]orums • [[**C**](#contents)]hat • [[**tele**](#contents)]gram • [[**web**](#contents)]site
• [[**ϟ**](#contents)] related resource • [[**>**](#contents)] related section • [[**>>**](#contents)] another page on site.

## Contents
* [What is Decentralized ID?](#what-is-decentralized-id)
* [What is Self Sovereign Identity?](#self-sovereign-identity)
* [Directory](#directory)
* [Sources](#sources)
* [Tips Jar](#tips-jar)

---

* [Edit this Page](https://github.com/infominer33/DIDecentralized)
* [infominer.id](https://infominer.id)

*Pull Requests Welcome*




![](https://i.imgur.com/9KpJRDr.png)


## What is Decentralized ID?

That's a big question, and what follows are just some notes, until I work out a more thoughtful answer.

The essence of Decentralized-ID is in creating open standards for a privacy preserving internet-wide identity layer — not owned by any one particular organization, but interoperable between all.

It's impossible to have a conversation about decentralized-id without discussing blockchain and self sovereign identity: 
  * Self Sovereign Identity principles (with some help from the GDPR) have helped to shape the narrative around putting the identity owner in control over their personal information.
  * Excitement over Blockchain Tech has spilled over in support of longstanding efforts to create a privacy preserving internet-wide identity protocol, and inspired development of decentralized networks for online identification. 
  * The United Nations Sustainable Development Goals (SDGs) have also fueled efforts towards a global and widely accessible identity solution.



## Self Sovereign Identity

![](https://imgur.com/3zz62kpl.png)


* [Christopher Allen](http://www.lifewithalacrity.com/)[[**info**](https://christophera.info/)] details the overarching history of internet idenitity standards and outlines [10 Principles of Self Sovereign Identity](https://github.com/WebOfTrustInfo/self-sovereign-identity/blob/master/self-sovereign-identity-principles.md) in his seminal work [The Path to Self-Soverereign Identity](http://www.lifewithalacrity.com/2016/04/the-path-to-self-soverereign-identity.html)[[**ϟ**](https://www.coindesk.com/path-self-sovereign-identity/amp/)]
* <a href="https://github.com/jandrieu/rebooting-the-web-of-trust-fall2016/raw/master/topics-and-advance-readings/a-technology-free-definition-of-self-sovereign-identity.pdf"><u>A Technlogy-Free Definition of Self-Sovereign Identity</u></a> is a continuation of the discussion started by Allen, offering 3 "Core Characteristics of Sovereign Identity".
* [7 Myths of Self Sovereign Identity](https://medium.com/evernym/7-myths-of-self-sovereign-identity-67aea7416b1)
* [Inevitable Rise of Self-Sovereign Identity](https://sovrin.org/wp-content/uploads/2018/03/The-Inevitable-Rise-of-Self-Sovereign-Identity.pdf)
* [SSIMeetup](http://ssimeetup.org/) [[**S**](https://www.slideshare.net/SSIMeetup/presentations)] [[**V**](https://www.youtube.com/channel/UCSqSTlKdbbCM1muGOhDa3Og)] [[**tele**](https://t.me/SSIMeetup)]
\- SSI Meetup is an open, collaborative community to help SSI evangelists around the world, independent of company interests or standards. 
* [SSI: A Roadmap for Adoption](https://github.com/WebOfTrustInfo/rebooting-the-web-of-trust-spring2018/blob/master/final-documents/a-roadmap-for-ssi.md)
* [Matching Identity Management Solutions to Self Sovereign Identity Solutions](https://www.slideshare.net/TommyKoens/matching-identity-management-solutions-to-selfsovereign-identity-principles)
<blockquote class="twitter-tweet" data-lang="en"><p lang="en" dir="ltr">0/ “Self-Sovereign Identity: A Progress Report”…</p>&mdash; Christopher Allen (@ChristopherA) <a href="https://twitter.com/ChristopherA/status/989120215702261761?ref_src=twsrc%5Etfw">April 25, 2018</a></blockquote>

* **[/DIDecentralized/self-sovereign-identity](self-sovereign-identity)** SSI documentation is still under development. This directory is to organize existing thought on SSI in one place for ease of study, and the development of new documentation.






## Directory
To other pages within this repository.

  * [SSI\DID History]({{ site.baseurl }}{{ site.baseurl }}/history/) 
    * [Losing Control over our Personal Information]({{ site.baseurl }}/history/#losing-control-over-our-personal-information) '80s
    * [PGP - Web of Trust]({{ site.baseurl }}/history/#pgp---web-of-trust) '91
    * [International Planetwork Conference]({{ site.baseurl }}/history/#international-planetwork-conference) '00s
    * [XNS Public Trust Organization]({{ site.baseurl }}/history/#xns-public-trust-organization)
    * [The Augmented Social Network]({{ site.baseurl }}/history/#the-augmented-social-network) '03
    * [IDCommons]({{ site.baseurl }}/history/#idcommons) '01
    * [Identity Gang]({{ site.baseurl }}/history/#identity-gang) '04
      * [Kim Cameron - Laws of Identity]({{ site.baseurl }}/history/#kim-cameron---laws-of-identity) 
    * [Internet Identity Workshop—IIW]({{ site.baseurl }}/history/#internet-identity-workshop) '05
    * [W3C Credentials Community Group]({{ site.baseurl }}/history/#w3c-credentials-community-group) '14 
    * [Bitnation]({{ site.baseurl }}/history/#bitnation) '15
    * [The United Nations Sustainable Development Goals]({{ site.baseurl }}/history/#the-united-nations-sustainable-development-goals) '15
    * [Rebooting-Web-of-Trust (/RWoT)]({{ site.baseurl }}/history/#rebooting-the-web-of-trust)
    * [Evernym]({{ site.baseurl }}/history/#evernym)
    * [ID2020 and the GDPR]({{ site.baseurl }}/history/#id2020-and-the-gdpr) '16
    * [The End of 2016]({{ site.baseurl }}/history/#the-end-of-2016)
    * [Decentralized Identity Foundation]({{ site.baseurl }}/history/#decentralized-identity-foundation) '17
    * [DID Standards History]({{ site.baseurl }}/history/#standards-history)
* [Self Sovereign Identity]({{ site.baseurl }}/self-sovereign-identity) 
  * [Evolution of SSI]({{ site.baseurl }}/self-sovereign-identity/evolution-of-ssi/) 
  * [SSI Principles vs Characteristics]({{ site.baseurl }}/self-sovereign-identity/ssi-principles-vs-characteristics/) 
  * [User Experience]({{ site.baseurl }}/self-sovereign-identity/user-experience/) 
* [DID Related Web Standards]({{ site.baseurl }}/standards) 
  * [XDI]({{ site.baseurl }}/standards/#xdi) 
    * [OASIS XDI TC Technical Committee on GitHub]({{ site.baseurl }}/standards/#oasis-xdi-tech-committee-on-github) 
  * [W3C]({{ site.baseurl }}/standards/#w3c) 
    * [DID the Decentralized Identifier]({{ site.baseurl }}/standards/#did-the-decentralized-identifier) 
    * [Verifiable Claims]({{ site.baseurl }}/standards/#verifiable-claims) 
  * [DID Auth]({{ site.baseurl }}/standards/#did-auth) 
  * [Decentralized Key Managment DKMS]({{ site.baseurl }}/standards/#decentralized-key-management-agents) 
  * [Ethereum ERC-EIP]({{ site.baseurl }}/standards/#ethereum-erc-eip)
  * [Blockcerts]({{ site.baseurl }}/standards/#blockcerts) 
  * [Schema]({{ site.baseurl }}/standards/#schema) 
* [DID Adoption]({{ site.baseurl }}/adoption/) 
* [GDPR]({{ site.baseurl }}/gdpr) 
* [Humanitarian]({{ site.baseurl }}/humanitarian/) 
* [Identity Related GitHub Repositories]({{ site.baseurl }}/identity-github/) 
* [Literature]({{ site.baseurl }}/literature/) 
* [Workshops]({{ site.baseurl }}/workshops) 
  * [Rebooting Web of Trust]({{ site.baseurl }}/workshops/rebooting-web-of-trust/) 
* [Media]({{ site.baseurl }}/media/)  (Video, Podcasts and Slideshare) 
* [Organizations]({{ site.baseurl }}/organizations) 
  * [Decentralized Identity Foundation—DIF]({{ site.baseurl }}/organizations/identity-foundation/) 
  * [My Data]({{ site.baseurl }}/organizations/mydata/)
  * [Sovrin Foundation]({{ site.baseurl }}/organizations/sovrin.foundation/) 
  * [SSI Meetup]({{ site.baseurl }}/organizations/ssi-meetup/)
* [DID\SSI Initiatives]({{ site.baseurl }}/id-initiatives) 
  * [Bitcoin]({{ site.baseurl }}/id-initiatives/bitcoin/) 
    * [BTCR]({{ site.baseurl }}/id-initiatives/bitcoin/#btcr)
    * [RWoT BTCR]({{ site.baseurl }}/id-initiatives/bitcoin/#rwot-btcr)
    * [Bitnation]({{ site.baseurl }}/id-initiatives/bitcoin/#bitnation)
    * [Spidchain]({{ site.baseurl }}/id-initiatives/bitcoin/#spidchain) 
  * [Blockstack]({{ site.baseurl }}/id-initiatives/blockstack/)
  * [Blockpass]({{ site.baseurl }}/id-initiatives/blockpass/)
  * [Danube]({{ site.baseurl }}/id-initiatives/danube/)
  * [Democracy Earth]({{ site.baseurl }}/id-initiatives/democracy-earth/)
  * [Digital Bazaar]({{ site.baseurl }}/id-initiatives/digital-bazaar/)
  * [Ethereum]({{ site.baseurl }}/id-initiatives/ethereum/) 
    * [ERC-EIP]({{ site.baseurl }}/id-initiatives/ethereum/#erc-eip) 
    * [ERC725-735]({{ site.baseurl }}/id-initiatives/ethereum/erc725-735)
    * [uPort]({{ site.baseurl }}/id-initiatives/ethereum/uport/) 
    * [Jolocom]({{ site.baseurl }}/id-initiatives/ethereum/#jolocom) 
    * [Spidchain]({{ site.baseurl }}/id-initiatives/ethereum/#spidchain) 
    * [Cryptonomica]({{ site.baseurl }}/id-initiatives/ethereum/cryptonomica/) 
    * [Assorted Ethereum Apps]({{ site.baseurl }}/id-initiatives/ethereum/#assorted-ethereum-apps) 
  * [Handshake]({{ site.baseurl }}/id-initiatives/handshake/)
  * [Indy]({{ site.baseurl }}/id-initiatives/indy-ecosystem/) 
    * [Adoption]({{ site.baseurl }}/id-initiatives/indy-ecosystem/adoption/) 
    * [Indy Github]({{ site.baseurl }}/id-initiatives/indy-ecosystem/indy-github/) 
    * [Literature]({{ site.baseurl }}/id-initiatives/indy-ecosystem/literature/) 
    * [VON]({{ site.baseurl }}/id-initiatives/indy-ecosystem/VON/) 
  * [IBM]({{ site.baseurl }}/id-initiatives/ibm/) 
  * [Microsoft]({{ site.baseurl }}/id-initiatives/microsoft/) 
  * [Ontology]({{ site.baseurl }}/id-initiatives/ontology/)
  * [Spid-chain]({{ site.baseurl }}/id-initiatives/spid-chain/)
  * [Danube Tech]({{ site.baseurl }}/id-initiatives/danube/)  
* [Hyperledger Global Forum]({{ site.baseurl }}/hgf-2018/) 
* [State Sponsored]({{ site.baseurl }}/state-sponsored/) 



## Sources
* [SSI Meetup](http://ssimeetup.org/) [[**V**](https://www.youtube.com/channel/UCSqSTlKdbbCM1muGOhDa3Og)][[**ϟ**](https://www.slideshare.net/SSIMeetup/presentations/)] 
* [IIW-Wiki](https://iiw.idcommons.net/Main_Page)
* [wiki.idcommons.net](http://wiki.idcommons.net/Main_Page)
* [/WebOfTrustInfo](https://github.com/WebOfTrustInfo/)
* [/peacekeeper/blockchain-identity](https://github.com/peacekeeper/blockchain-identity)
* [identitywoman.net](https://identitywoman.net/)
* [windley.com/tags/identity](http://www.windley.com/tags/identity.shtml)
* [Kim Camerons Identity Blog](https://identityblog.com)

---

## Tips Jar

BTC— 1GvkjHtiy9LUjVkStnEAXxjhcoS56aCokY

![](https://imgur.com/yXLLm9Bl.png) 

DOGE— DSzMxfABB8EwKiumzV7YHhS7HTvWAyM7QF

![](https://i.imgur.com/0zBLoUP.png) 

...